shelter-fs is a zero-details, privacy-focused file system.
It keeps your app files securely, privately and reliably on underlying storages. By encapsulating files and directories into an encrypted repository, it provides a virtual file system and exclusive access to the authorised application.
The most core parts of this module are Repo and File, which provides
most API for file system operations and file data I/O.
Repoprovides similar file system manipulation methods tostd::fsFileprovides similar file I/O methods tostd::fs::File
Examples
Create and open a Repository using memory as underlying storage.
TODO[epic=doc,seq=21] Intro documentation
Structs
- File
System Options - Repository
- TODO[epic=doc] Repository
Enums
- Error
- The error type for operations with
RepositoryandFile.